@@ -169,6 +169,11 @@ modifyListNA <- function(x, val) {
 # modifyListNA(l2, l1)
 
 
+match.arg2 <- function(arg, choices, several.ok = TRUE) {
+  sapply(arg, match.arg, choices = choices, several.ok = several.ok)
+}
+
+
 # //////////////////////////////////////////////////////////////////////////////
 #' bring vector values into ring form
 #'
@@ -834,6 +839,44 @@ angle <- function(x, y) {
 }
 
 
+# is_integerish(1)
+# is_integerish(1.0)
+# is_integerish(c(1.0, 2.0))
+is_integerish <- function(x) {
+  ii <- all(is.numeric(x) | is.integer(x))
+  jj <- all(x == as.integer(x))
+  ii && jj
+}
+
+
+#' convert element index or name to index
+#' @examples
+#' fortify_element_id(boeker, "self")
+#' fortify_element_id(boeker, 1)
+#' @noRd
+fortify_element_id <- function(x, element) {
+  stop_if_not_in_element_range(x, element)
+  if (is.character(element)) {
+    element <- which(elements(x) == element)
+  }
+  element
+}
+
+
+#' convert element index or name to name
+#' @examples
+#' fortify_element_name(boeker, 1)
+#' fortify_element_name(boeker, "self")
+#' @noRd
+fortify_element_name <- function(x, element) {
+  stop_if_not_in_element_range(x, element)
+  if (is.numeric(element)) {
+    element <- elements(x)[element]
+  }
+  element
+}
+
+
 # //////////////////////////////////////////////////////////////////////////////
 ###                           FORMATTING                                   ####
 # //////////////////////////////////////////////////////////////////////////////
@@ -978,3 +1021,32 @@ list_to_dataframe <- function(l) {
   # plyr:::list_to_dataframe(l)
   do.call(rbind.data.frame, l)
 }
+
+
+`%||%` <- function(a, b) {
+  if (!is.null(a)) {
+    a
+  } else {
+    b
+  }
+}
+
+
+# Get list names
+# returns vector with same length as list. NA if list entry has no name.
+get_names_na <- function(x) {
+  nm <- names(x)
+  if (is.null(nm)) {
+    rep(NA_character_, length(x))
+  } else {
+    ifelse(nzchar(nm), nm, NA_character_)
+  }
+}
+
+# from tools::file_path_sans_ext
+file_path_sans_ext <- function(x, compression = FALSE) {
+  if (compression) {
+    x <- sub("[.](gz|bz2|xz)$", "", x)
+  }
+  sub("([^.]+)\\.[[:alnum:]]+$", "\\1", x)
+}
